@@ -2,23 +2,25 @@
 # -*- coding: utf-8 -*-
 
 # -------------------------------------------------------------------
-# Copyright (c) 2010-2020 Denis Machard
-# This file is part of the extensive automation project
+# Copyright (c) 2010-2021 Denis Machard
 #
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation; either
-# version 2.1 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-# MA 02110-1301 USA
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 # -------------------------------------------------------------------
 
 import sys
@@ -40,6 +42,7 @@ except ImportError:  # support python 3
     import pickle as cPickle
 from pathlib import Path
 import yaml
+import uuid
 
 from ea.libs import Settings, Logger
 from ea.libs.FileModels import TestResult as TestResult
@@ -391,6 +394,45 @@ class CliFunctions(Logger.ClassLogger):
 
         sys.stdout.flush()
 
+    def generate_token(self, token_name):
+        """generate token for remote agents"""
+        
+        sql_query = "SELECT * from agents WHERE name=\"%s\"" % (token_name)
+        rows = querySQL(query=sql_query, db=db_name)
+        if len(rows):
+            print("error: token name already used")
+            return
+            
+        token_uuid = str(uuid.uuid4())
+        
+        sql_query = "INSERT INTO `agents` "
+        sql_query += "(`token`, `name`, `project_id`) "
+        sql_query += "VALUES ('%s', '%s', %s);" % (token_uuid,
+                                                   token_name,
+                                                   "1")
+                                                   
+        querySQL(query=sql_query, db=db_name)
+        print("%s %s" % (token_name, token_uuid) )
+        
+    def delete_token(self, token_name):
+        """delete token by name"""
+        sql_query = "SELECT * from agents WHERE name=\"%s\"" % (token_name)
+        rows = querySQL(query=sql_query, db=db_name)
+        if not len(rows):
+            print("error: token name does not exist")
+            return
+            
+        sql_query = "DELETE FROM `agents` "
+        sql_query += "WHERE name=\"%s\"" % token_name
+        querySQL(query=sql_query, db=db_name)
+        
+    def list_tokens(self):
+        """list all tokens for agents"""
+        sql_query = "SELECT * from agents"
+        rows = querySQL(query=sql_query, db=db_name)
+        for r in rows:
+            print("%s %s" % (r["name"], r["token"]) )
+            
     def show_data_storage(self):
         """show data storage path"""
         storage = "%s%s" % (Settings.getDirExec(),
@@ -570,12 +612,12 @@ def instance():
     return CLI
 
 
-def initialize(parent):
+def initialize(*args, **kwargs):
     """
     Instance creation
     """
     global CLI
-    CLI = CliFunctions(parent=parent)
+    CLI = CliFunctions(*args, **kwargs)
 
 
 def finalize():
