@@ -2,23 +2,25 @@
 # -*- coding: utf-8 -*-
 
 # -------------------------------------------------------------------
-# Copyright (c) 2010-2020 Denis Machard
-# This file is part of the extensive automation project
+# Copyright (c) 2010-2021 Denis Machard
 #
-# This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation; either
-# version 2.1 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-# MA 02110-1301 USA
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 # -------------------------------------------------------------------
 
 import threading
@@ -147,10 +149,8 @@ def check_agent(caller, agent, agent_support, agent_type):
                 type(agent))
         if not len(agent['name']):
             raise ValueException(caller, "agent name cannot be empty")
-        if agent['type'] != agent_type:
-            raise ValueException(
-                caller, 'Bad agent type: %s, expected: %s' %
-                (agent['type'], agent_type))
+        if "type" not in agent:
+            agent["type"] = agent_type
 
 
 class AdapterException(Exception):
@@ -166,10 +166,11 @@ class AdapterException(Exception):
     def __str__(self):
         """
         """
-        # sut adapters path normalized, remove double // or more
-        sut = re.sub("/{2,}", "/", getMainPath())
+        # normalize path
+        sut = os.path.normpath(getMainPath())
+        orig = os.path.normpath(self.orig[0])
 
-        f = self.orig[0].split(sut)[1]
+        f = orig.split(sut)[1]
         ret = "Adapter.%s > %s" % (self.orig[2], self.msg)
         ret += '\nFile: %s' % f
         ret += '\nLine error: %s' % self.orig[1]
@@ -190,9 +191,10 @@ class ValueException(Exception):
         """
         """
         # sut adapters path normalized, remove double // or more
-        sut = re.sub("/{2,}", "/", getMainPath())
+        sut = os.path.normpath(getMainPath())
+        orig = os.path.normpath(self.orig[0])
 
-        f = self.orig[0].split(sut)[1]
+        f = orig.split(sut)[1]
         ret = "Adapter.%s > %s" % (self.orig[2], self.msg)
         ret += '\nFile: %s' % f
         ret += '\nLine error: %s' % self.orig[1]
@@ -337,13 +339,12 @@ ADAPTER_NAME = "Adapter"
 
 
 class Adapter(threading.Thread):
-    """
-    Adapter class
-    """
-
+    """Adapter class"""
     def __init__(self, parent, name, realname=None, debug=False,
-                 showEvts=True, showSentEvts=True, showRecvEvts=True, shared=False,
-                 agentSupport=False, agent=None, timeoutSleep=0.1, caller=None,
+                 showEvts=True, showSentEvts=True, 
+                 showRecvEvts=True, shared=False,
+                 agentSupport=False, agent=None,
+                 timeoutSleep=0.1, caller=None,
                  agentType=None):
         """
         All adapters must inherent from this class
@@ -378,7 +379,7 @@ class Adapter(threading.Thread):
         self.last_event_queue = None
         self.timeoutSleep = timeoutSleep
 
-        self.__agentSupport = agentSupport
+        self.__agentSupport = agentSupport 
         self.__agentName = agent
         self.__agentType = agentType
         self.__caller = caller
